@@ -22,9 +22,10 @@ import time
 import pwd,grp
 import datetime
 import signal
+import sys
+import pyzm.helpers.globals as g
 
 
-logger = None
 pid = None
 process_name = None
 inited = False
@@ -135,6 +136,7 @@ def init(name=None, override={}):
             config[key] = override[key]
     
 
+
     # read all config files in order
     files=[]
     for f in glob.glob(config['conf_path']+'/conf.d/*.conf'):
@@ -227,6 +229,11 @@ def init(name=None, override={}):
     except Exception as e:
         Error('Error setting up signal handler: {}'.format(e))
 
+    g.logger = sys.modules[__name__]
+    #print (sys.modules[__name__])
+    Info ('Switching global logger to ZMLog')
+
+
 def sig_log_rot(sig,frame):
     #time.sleep(3) # do we need this?
     global log_reload_needed, inited, logger_name, logger_overrides
@@ -391,7 +398,7 @@ def Debug(level=1, message=None,caller=None):
     global logger, pid, process_name, inited, config, engine, conn, connected, levels, priorities, config_table, log_table, meta, log_fname, log_fhandle
     target = config['log_debug_target']
 
-    if target:
+    if target and not config['dump_console']:
         targets = [x.strip().lstrip('_') for x in target.split('|')]
         # if current name does not fall into debug targets don't log
         if not any(map(process_name.startswith, targets)):
