@@ -213,8 +213,6 @@ class Yolo(Base):
         label = []
         conf = []
 
-        prefix = '(yolo) ' if self.options.get('show_models')=='yes' else ''
-
         # now filter out with configured yolo confidence, so we can see rejections in log
         for i in indices:
             i = i[0]
@@ -231,7 +229,7 @@ class Yolo(Base):
                 int(round(x + w)),
                 int(round(y + h))
             ])
-            label.append(prefix+str(self.classes[class_ids[i]]))
+            label.append(str(self.classes[class_ids[i]]))
             conf.append(confidences[i])
            
         if downscaled:
@@ -243,4 +241,4 @@ class Yolo(Base):
                 box[2] = round (box[2] * upsize_xfactor)
                 box[3] = round (box[3] * upsize_yfactor)
         
-        return bbox, label, conf
+        return bbox, label, conf, ['yolo']*len(label)
